# -*- coding: utf-8 -*-

AGENT_LOGGER_NAME = 'flylog'
AGENT_HOST = '127.0.0.1'
AGENT_PORT = 12000
